@@ -20,7 +20,7 @@ def run(args, index):
                 kw = dict([path.split('=')])
                 index.remove(**kw)
             else:
-                index.remove(path=path, clear=args.get('--clear'))
+                index.remove(path=path, clear=args.get('clear'))
             index.save()
     finally:
         index.release()
